@@ -1,5 +1,5 @@
 /*
- * $Id: xsh.c,v 1.3 2001/02/05 06:50:41 agmorgan Exp $
+ * $Id: xsh.c,v 1.6 2001/12/09 22:39:03 agmorgan Exp $
  */
 
 /* Andrew Morgan (morgan@kernel.org) -- an example application
@@ -11,6 +11,12 @@
 #include <security/pam_appl.h>
 #include <security/pam_misc.h>
 
+#include <security/_pam_aconf.h>
+
+#include <pwd.h>
+#include <sys/types.h>
+#include <unistd.h>
+
 /* ------ some local (static) functions ------- */
 
 static void bail_out(pam_handle_t *pamh,int really, int code, const char *fn)
@@ -43,7 +49,7 @@ int main(int argc, char **argv)
      if (argc > 3) {
 	  fprintf(stderr,"usage: %s [username [service-name]]\n",argv[0]);
      }
-     if (argc >= 2) {
+     if ((argc >= 2) && (argv[1][0] != '-')) {
 	  username = argv[1];
      }
      if (argc == 3) {
@@ -54,6 +60,34 @@ int main(int argc, char **argv)
      retcode = pam_start(service, username, &conv, &pamh);
      bail_out(pamh,1,retcode,"pam_start");
 
+     /* fill in the RUSER and RHOST etc. fields */
+     {
+	 char buffer[100];
+	 struct passwd *pw;
+	 const char *tty;
+
+	 pw = getpwuid(getuid());
+	 if (pw != NULL) {
+	     retcode = pam_set_item(pamh, PAM_RUSER, pw->pw_name);
+	     bail_out(pamh,1,retcode,"pam_set_item(PAM_RUSER)");
+	 }
+
+	 retcode = gethostname(buffer, sizeof(buffer)-1);
+	 if (retcode) {
+	     perror("failed to look up hostname");
+	     retcode = pam_end(pamh, PAM_ABORT);
+	     bail_out(pamh,1,retcode,"pam_end");
+	 }
+	 retcode = pam_set_item(pamh, PAM_RHOST, buffer);
+	 bail_out(pamh,1,retcode,"pam_set_item(PAM_RHOST)");
+
+	 tty = ttyname(fileno(stdin));
+	 if (tty) {
+	     retcode = pam_set_item(pamh, PAM_TTY, tty);
+	     bail_out(pamh,1,retcode,"pam_set_item(PAM_RHOST)");
+	 }
+     }
+
      /* to avoid using goto we abuse a loop here */
      for (;;) {
 	  /* authenticate the user --- `0' here, could have been PAM_SILENT
