@@ -1,17 +1,7 @@
 /*
  * pam_auth.c -- PAM authentication
  *
- * $Id: pam_auth.c,v 1.1.1.1 2000/06/20 22:11:13 agmorgan Exp $
- *
- * $Log: pam_auth.c,v $
- * Revision 1.1.1.1  2000/06/20 22:11:13  agmorgan
- * Imported 0.72 Linux-PAM sources
- *
- * Revision 1.1.1.1  1998/07/12 05:17:15  morgan
- * Linux PAM sources pre-0.66
- *
- * Revision 1.7  1997/04/05 06:53:52  morgan
- * fail-delay changes
+ * $Id: pam_auth.c,v 1.3 2001/01/22 06:07:28 agmorgan Exp $
  *
  */
 
@@ -26,6 +16,13 @@ int pam_authenticate(pam_handle_t *pamh, int flags)
 
     D(("pam_authenticate called"));
 
+    IF_NO_PAMH("pam_authenticate", pamh, PAM_SYSTEM_ERR);
+
+    if (__PAM_FROM_MODULE(pamh)) {
+	D(("called from module!?"));
+	return PAM_SYSTEM_ERR;
+    }
+
     if (pamh->former.choice == PAM_NOT_STACKED) {
 	_pam_sanitize(pamh);
 	_pam_start_timer(pamh);    /* we try to make the time for a failure
@@ -33,7 +30,6 @@ int pam_authenticate(pam_handle_t *pamh, int flags)
 				      fail */
     }
 
-    IF_NO_PAMH("pam_authenticate",pamh,PAM_SYSTEM_ERR);
     retval = _pam_dispatch(pamh, flags, PAM_AUTHENTICATE);
 
     if (retval != PAM_INCOMPLETE) {
@@ -51,9 +47,14 @@ int pam_setcred(pam_handle_t *pamh, int flags)
 {
     int retval;
 
+    D(("pam_setcred called"));
+
     IF_NO_PAMH("pam_setcred", pamh, PAM_SYSTEM_ERR);
 
-    D(("pam_setcred called"));
+    if (__PAM_FROM_MODULE(pamh)) {
+	D(("called from module!?"));
+	return PAM_SYSTEM_ERR;
+    }
 
     if (! flags) {
 	flags = PAM_ESTABLISH_CRED;
