@@ -4,7 +4,7 @@
  * Copyright (c) Andrew G. Morgan <morgan@kernel.org> 1996-9
  * All rights reserved.
  *
- * $Id: pam_delay.c,v 1.3 2001/01/22 06:07:28 agmorgan Exp $
+ * $Id: pam_delay.c,v 1.5 2001/11/26 03:04:47 agmorgan Exp $
  *
  */
 
@@ -14,6 +14,7 @@
  */
 
 #include <unistd.h>
+#include <time.h>
 #include "pam_private.h"
 
 /* **********************************************************************
@@ -133,7 +134,7 @@ void _pam_await_timer(pam_handle_t *pamh, int status)
 
 int pam_fail_delay(pam_handle_t *pamh, unsigned int usec)
 {
-     int largest;
+     unsigned int largest;
 
      IF_NO_PAMH("pam_fail_delay", pamh, PAM_SYSTEM_ERR);
 
