@@ -2,9 +2,9 @@
 
 /*
  * created by Marc Ewing.
- * Currently maintained by Andrew G. Morgan <morgan@linux.kernel.org>
+ * Currently maintained by Andrew G. Morgan <morgan@kernel.org>
  *
- * $Id: pam_handlers.c,v 1.2 2001/01/22 06:07:28 agmorgan Exp $
+ * $Id: pam_handlers.c,v 1.6 2001/12/11 07:41:39 agmorgan Exp $
  *
  */
 
@@ -13,6 +13,9 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
+
 #ifdef PAM_DYNAMIC
 # ifdef PAM_SHL
 #  include <dl.h>
@@ -20,17 +23,10 @@
 #  include <dlfcn.h>
 # endif /* PAM_SHL */
 #endif /* PAM_DYNAMIC */
-#include <fcntl.h>
-#include <unistd.h>
 
 #include "pam_private.h"
 
-/* FreeBSD doesn't define this */
-#ifndef RTLD_NOW
-# define RTLD_NOW      1
-#endif
-
-/* If not required, define as nothing - FreeBSD needs it to be "_"... */
+/* If not required, define as nothing */
 #ifndef SHLIB_SYM_PREFIX
 # define SHLIB_SYM_PREFIX ""
 #endif
@@ -756,6 +752,8 @@ int _pam_add_handler(pam_handle_t *pamh
     (*handler_p)->must_fail = must_fail;        /* failure forced? */
     (*handler_p)->func = func;
     memcpy((*handler_p)->actions,actions,sizeof((*handler_p)->actions));
+    (*handler_p)->cached_retval = _PAM_INVALID_RETVAL;
+    (*handler_p)->cached_retval_p = &((*handler_p)->cached_retval);
     (*handler_p)->argc = argc;
     (*handler_p)->argv = argv;                       /* not a copy */
     (*handler_p)->next = NULL;
@@ -775,6 +773,9 @@ int _pam_add_handler(pam_handle_t *pamh
 	(*handler_p2)->must_fail = must_fail;        /* failure forced? */
 	(*handler_p2)->func = func2;
 	memcpy((*handler_p2)->actions,actions,sizeof((*handler_p2)->actions));
+	(*handler_p2)->cached_retval =  _PAM_INVALID_RETVAL;     /* ignored */
+	/* Note, this next entry points to the handler_p value! */
+	(*handler_p2)->cached_retval_p = &((*handler_p)->cached_retval);
 	(*handler_p2)->argc = argc;
 	if (argv) {
 	    if (((*handler_p2)->argv = malloc(argvlen)) == NULL) {
