@@ -1,7 +1,7 @@
 /* pam_strerror.c */
 
 /*
- * $Id: pam_strerror.c,v 1.2 2000/12/04 19:02:34 baggins Exp $
+ * $Id: pam_strerror.c,v 1.3 2002/05/29 06:35:47 agmorgan Exp $
  */
 
 #include "pam_private.h"
@@ -89,5 +89,5 @@ const char *pam_strerror(pam_handle_t *pamh, int errnum)
 	return "Application needs to call libpam again";
     }
 
-    return "Unknown Linux-PAM error (need to upgrde libpam?)";
+    return "Unknown PAM error";
 }
