@@ -30,8 +30,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
-/* man page says above file includes this... */
-extern int gethostname(char *name, size_t len);
 
 #include <stdarg.h>
 #include <syslog.h>
@@ -87,7 +85,7 @@ int strcasecmp(const char *s1, const char *s2);
 
  /* Delimiters for fields and for lists of users, ttys or hosts. */
 
-static const char fs[] = ":";			/* field separator */
+static const char *fs = ":";			/* field separator */
 static const char sep[] = ", \t";		/* list-element separator */
 
  /* Constants to be used in assignments only, not in comparisons... */
@@ -126,7 +124,12 @@ static int parse_args(struct login_info *loginfo, int argc, const char **argv)
     int i;
 
     for (i=0; i<argc; ++i) {
-	if (!strncmp("accessfile=", argv[i], 11)) {
+	if (!strncmp("fieldsep=", argv[i], 9)) {
+
+	    /* the admin wants to override the default field separators */
+	    fs = argv[i]+9;
+
+	} else if (!strncmp("accessfile=", argv[i], 11)) {
 	    FILE *fp = fopen(11 + argv[i], "r");
 
 	    if (fp) {
@@ -345,8 +348,9 @@ static int from_match(char *tok, struct login_info *item)
            by "string" starts from "tok".
                                1998/01/27  Andrey V. Savochkin <saw@msu.ru>
          */
+
         struct hostent *h;
-        char hn[3+1+3+1+3+1+3+1];
+        char hn[3+1+3+1+3+1+3+1+1];
         int r;
 
         h = gethostbyname(string);
@@ -356,9 +360,9 @@ static int from_match(char *tok, struct login_info *item)
 	    return (NO);
         if (h->h_length != 4)
 	    return (NO); /* only IPv4 addresses (SAW) */
-        r = snprintf(hn, sizeof(hn), "%u.%u.%u.%u",
-                (unsigned char)h->h_addr[0], (unsigned char)h->h_addr[1],
-                (unsigned char)h->h_addr[2], (unsigned char)h->h_addr[3]);
+        r = snprintf(hn, sizeof(hn), "%u.%u.%u.%u.",
+		     (unsigned char)h->h_addr[0], (unsigned char)h->h_addr[1],
+		     (unsigned char)h->h_addr[2], (unsigned char)h->h_addr[3]);
         if (r < 0 || r >= sizeof(hn))
 	    return (NO);
         if (!strncmp(tok, hn, tok_len))
@@ -426,7 +430,7 @@ PAM_EXTERN int pam_sm_acct_mgmt(pam_handle_t *pamh,int flags,int argc
 	return PAM_ABORT;
     }
 
-    if (from==NULL) {
+    if ((from==NULL) || (*from=='\0')) {
 
         /* local login, set tty name */
 
