@@ -1,7 +1,7 @@
 /* pam_lastlog module */
 
 /*
- * $Id: pam_lastlog.c,v 1.2 2000/11/19 23:54:04 agmorgan Exp $
+ * $Id: pam_lastlog.c,v 1.4 2001/10/12 05:56:26 agmorgan Exp $
  *
  * Written by Andrew Morgan <morgan@linux.kernel.org> 1996/3/11
  *
@@ -25,7 +25,6 @@
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
-#define __USE_BSD
 #include <syslog.h>
 #include <unistd.h>
 
@@ -335,8 +334,9 @@ static int last_login_date(pam_handle_t *pamh, int announce, uid_t uid)
 	    }
 
 	    /* copy to last_login */
-	    strncpy(last_login.ll_host, remote_host
-		    , sizeof(last_login.ll_host));
+	    strncpy(last_login.ll_host, remote_host,
+		    sizeof(last_login.ll_host));
+	    last_login.ll_host[sizeof(last_login.ll_host) - 1] = '\0';
 	    remote_host = NULL;
 
 	    /* set the terminal line */
@@ -351,8 +351,9 @@ static int last_login_date(pam_handle_t *pamh, int announce, uid_t uid)
 	    D(("terminal = %s", terminal_line));
 
 	    /* copy to last_login */
-	    strncpy(last_login.ll_line, terminal_line
-		    , sizeof(last_login.ll_line));
+	    strncpy(last_login.ll_line, terminal_line,
+		    sizeof(last_login.ll_line));
+	    last_login.ll_host[sizeof(last_login.ll_host) - 1] = '\0';
 	    terminal_line = NULL;
 
 	    D(("locking last_log file"));
