@@ -1,7 +1,7 @@
 /* pam_nologin module */
 
 /*
- * $Id: pam_nologin.c,v 1.3 2002/06/27 05:43:28 agmorgan Exp $
+ * $Id: pam_nologin.c,v 1.4 2002/07/13 05:10:54 agmorgan Exp $
  *
  * Written by Michael K. Johnson <johnsonm@redhat.com> 1996/10/24
  *
@@ -24,6 +24,7 @@
  */
 
 #define PAM_SM_AUTH
+#define PAM_SM_ACCOUNT
 
 #include <security/pam_modules.h>
 
@@ -192,6 +193,6 @@ struct pam_module _pam_nologin_modstruct = {
      NULL,
 };
 
-#endif
+#endif /* PAM_STATIC */
 
 /* end of module definition */
