@@ -1,5 +1,5 @@
 /*
- * $Id: pam_pwdb.c,v 1.5 1999/07/08 05:02:02 morgan Exp $
+ * $Id: pam_pwdb.c,v 1.3 2000/11/19 23:54:04 agmorgan Exp $
  *
  * This is the single file that will be compiled for pam_unix.
  * it includes each of the modules that have beed defined in the .-c
@@ -14,20 +14,13 @@
  */
 
 static const char rcsid[] =
-"$Id: pam_pwdb.c,v 1.5 1999/07/08 05:02:02 morgan Exp $\n"
+"$Id: pam_pwdb.c,v 1.3 2000/11/19 23:54:04 agmorgan Exp $\n"
 " - PWDB Pluggable Authentication module. <morgan@linux.kernel.org>"
 ;
 
 /* #define DEBUG */
 
-#define _SVID_SOURCE
-#define _BSD_SOURCE
-#define _BSD_COMPAT
-
-#ifdef linux
-# define _GNU_SOURCE
-# include <features.h>
-#endif
+#include <security/_pam_aconf.h>
 
 #include <sys/types.h>
 #include <stdarg.h>
@@ -83,7 +76,7 @@ PAM_EXTERN int pam_sm_authenticate(pam_handle_t *pamh, int flags
 
     if ( on(UNIX_LIKE_AUTH, ctrl) ) {
 	D(("recording return code for next time [%d]", retval));
-	pam_set_data(pamh, "pwdb_setcred_return", (void *) &retval, NULL);
+	pam_set_data(pamh, "pwdb_setcred_return", (void *) retval, NULL);
     }
 
     D(("done. [%s]", pam_strerror(pamh, retval)));
@@ -108,8 +101,7 @@ PAM_EXTERN int pam_sm_setcred(pam_handle_t *pamh, int flags
 	int *pretval = &retval;
 
 	D(("recovering return code from auth call"));
-	pam_get_data(pamh, "pwdb_setcred_return", (const void **) &pretval);
-	pam_set_data(pamh, "pwdb_setcred_return", NULL, NULL);
+	pam_get_data(pamh, "pwdb_setcred_return", (const void **) pretval);
 	D(("recovered data indicates that old retval was %d", retval));
     }
 
