@@ -1,7 +1,7 @@
 /* pam_rootok module */
 
 /*
- * $Id: pam_rootok.c,v 1.1.1.1 2000/06/20 22:11:56 agmorgan Exp $
+ * $Id: pam_rootok.c,v 1.3 2002/05/26 23:00:28 agmorgan Exp $
  *
  * Written by Andrew Morgan <morgan@linux.kernel.org> 1996/3/11
  */
@@ -12,6 +12,7 @@
 #include <unistd.h>
 #include <syslog.h>
 #include <stdarg.h>
+#include <string.h>
 
 /*
  * here, we make a definition for the externally accessible function
@@ -75,7 +76,7 @@ int pam_sm_authenticate(pam_handle_t *pamh,int flags,int argc
 	retval = PAM_SUCCESS;
 
     if (ctrl & PAM_DEBUG_ARG) {
-	_pam_log(LOG_DEBUG, "authetication %s"
+	_pam_log(LOG_DEBUG, "authentication %s"
 		 , retval==PAM_SUCCESS ? "succeeded":"failed" );
     }
 
