@@ -1,7 +1,7 @@
 /*
  * pam_tally.c
  * 
- * $Id: pam_tally.c,v 1.5 2001/01/20 22:21:22 agmorgan Exp $
+ * $Id: pam_tally.c,v 1.9 2001/12/09 21:44:58 agmorgan Exp $
  */
 
 
@@ -13,10 +13,15 @@
 
 #include <security/_pam_aconf.h>
 
+#if defined(MAIN) && defined(MEMORY_DEBUG)
+# undef exit
+#endif /* defined(MAIN) && defined(MEMORY_DEBUG) */
+
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
 #include <stdarg.h>
+#include <stdlib.h>
 #include <syslog.h>
 #include <pwd.h>
 #include <time.h>
@@ -84,6 +89,7 @@ static void _pam_log(int err, const char *format, ...)
 
 #ifdef MAIN
     vfprintf(stderr,format,args);
+    fprintf(stderr,"\n");
 #else
     openlog(MODULE_NAME, LOG_CONS|LOG_PID, LOG_AUTH);
     vsyslog(err, format, args);
@@ -184,14 +190,24 @@ static int get_tally( tally_t *tally,
     if ( fseek( *TALLY, uid * sizeof(struct faillog), SEEK_SET ) ) {
           _pam_log(LOG_ALERT, "fseek failed %s", filename);
                 return PAM_AUTH_ERR;
-     }
-                    
-
-    if (( fread((char *) &fsp->fs_faillog,
-		sizeof(struct faillog), 1, *TALLY) )==0 ) {
-          *tally=0; /* Assuming a gappy filesystem */
     }
-    *tally = fsp->fs_faillog.fail_cnt;    
+                    
+    if ( fileinfo.st_size <= uid * sizeof(struct faillog) ) {
+
+	memset(fsp, 0, sizeof(struct faillog));
+	*tally=0;
+	fsp->fs_faillog.fail_time = time(NULL);
+
+    } else if (( fread((char *) &fsp->fs_faillog,
+		       sizeof(struct faillog), 1, *TALLY) )==0 ) {
+
+	*tally=0; /* Assuming a gappy filesystem */
+
+    } else {
+
+	*tally = fsp->fs_faillog.fail_cnt;
+
+    }
               
     return PAM_SUCCESS;
   }
@@ -215,8 +231,8 @@ static int set_tally( tally_t tally,
         fsp->fs_faillog.fail_cnt = tally;                                    
         if (fwrite((char *) &fsp->fs_faillog,
 		   sizeof(struct faillog), 1, *TALLY)==0 ) {
-          _pam_log(LOG_ALERT, "tally update (fputc) failed.", filename);
-          return PAM_AUTH_ERR;
+	    _pam_log(LOG_ALERT, "tally update (fwrite) failed.", filename);
+	    return PAM_AUTH_ERR;
         }
       }
     
@@ -312,21 +328,22 @@ static int tally_bump (int inc,
 
     /* to remember old fail time (for locktime) */
     fsp->fs_fail_time = fsp->fs_faillog.fail_time;
-    fsp->fs_faillog.fail_time = (time_t) time( (time_t *) 0);
+    fsp->fs_faillog.fail_time = time(NULL);
     (void) pam_get_item(pamh, PAM_RHOST, (const void **)&remote_host);
-    if (!remote_host)
-    {
+    if (!remote_host) {
+
     	(void) pam_get_item(pamh, PAM_TTY, (const void **)&cur_tty);
-	if (!cur_tty)
-    	    strcpy(fsp->fs_faillog.fail_line, "unknown");
-	else {
+	if (!cur_tty) {
+    	    strncpy(fsp->fs_faillog.fail_line, "unknown",
+		    sizeof(fsp->fs_faillog.fail_line) - 1);
+	    fsp->fs_faillog.fail_line[sizeof(fsp->fs_faillog.fail_line)-1] = 0;
+	} else {
     	    strncpy(fsp->fs_faillog.fail_line, cur_tty,
-		    (size_t)sizeof(fsp->fs_faillog.fail_line));
+		    sizeof(fsp->fs_faillog.fail_line)-1);
 	    fsp->fs_faillog.fail_line[sizeof(fsp->fs_faillog.fail_line)-1] = 0;
 	}
-    }
-    else
-    {
+
+    } else {
     	strncpy(fsp->fs_faillog.fail_line, remote_host,
 		(size_t)sizeof(fsp->fs_faillog.fail_line));
 	fsp->fs_faillog.fail_line[sizeof(fsp->fs_faillog.fail_line)-1] = 0;
@@ -502,15 +519,14 @@ PAM_FUNCTION( pam_sm_acct_mgmt ) {
       if (fsp->fs_faillog.fail_locktime && fsp->fs_fail_time
 	  && (!no_lock_time) )
       {
-      	if ( (fsp->fs_faillog.fail_locktime + fsp->fs_fail_time)
-	     > (time_t)time((time_t)0) )
+      	if ( (fsp->fs_faillog.fail_locktime + fsp->fs_fail_time) > time(NULL) )
       	{ 
       		_pam_log(LOG_NOTICE,
 			 "user %s ("UID_FMT") has time limit [%lds left]"
 			 " since last failure.",
 			 user,uid,
 			 fsp->fs_fail_time+fsp->fs_faillog.fail_locktime
-			 -(time_t)time((time_t)0));
+			 -time(NULL));
       		return PAM_AUTH_ERR;
       	}
       }
@@ -689,7 +705,6 @@ int main ( int argc, char **argv ) {
       if ( ! fread((char *) &fsp->fs_faillog,
 		   sizeof (struct faillog), 1, TALLY)
 	   || ! fsp->fs_faillog.fail_cnt ) {
-      	tally=fsp->fs_faillog.fail_cnt;
       	continue;
       	}
       tally = fsp->fs_faillog.fail_cnt;	
