@@ -1,7 +1,7 @@
 /* pam_userdb module */
  
 /*
- * $Id: pam_userdb.c,v 1.4 2000/12/04 15:02:16 baggins Exp $
+ * $Id: pam_userdb.c,v 1.5 2001/11/26 03:27:40 agmorgan Exp $
  * Written by Cristian Gafton <gafton@redhat.com> 1996/09/10
  * See the end of the file for Copyright Information
  */
@@ -138,11 +138,14 @@ static int user_lookup(const char *user, const char *pass)
 
     if (data.dptr != NULL) {
 	int compare = 0;
-	/* bingo, got it */
-	if (ctrl & PAM_ICASE_ARG)
-	    compare = strncasecmp(pass, data.dptr, data.dsize);
-	else
-	    compare = strncmp(pass, data.dptr, data.dsize);
+	
+	if (strlen(pass) != data.dsize) {
+	    compare = 1;
+	} else if (ctrl & PAM_ICASE_ARG) {
+	    compare = strncasecmp(data.dptr, pass, data.dsize);
+	} else {
+	    compare = strncmp(data.dptr, pass, data.dsize);
+	}
 	dbm_close(dbm);
 	if (compare == 0)
 	    return 0; /* match */
